@@ -247,6 +247,8 @@ class Module(BaseModel):
     def spec_validator(cls, value: Optional[str]) -> machinery.ModuleSpec:
         spec: Optional[machinery.ModuleSpec] = None
 
+        # TODO: this should really work based off of the schema path
+        # and this should suport checking  just partial_types.py if we are in a `prisma` dir
         if value is None:
             value = 'prisma/partial_types.py'
 
@@ -731,7 +733,7 @@ class Field(BaseModel):
     is_generated: bool = FieldInfo(alias='isGenerated')
     is_updated_at: bool = FieldInfo(alias='isUpdatedAt')
 
-    default: Optional[Union['DefaultValue', str]]
+    default: Optional[Union['DefaultValue', str, List[object]]]
     has_default_value: bool = FieldInfo(alias='hasDefaultValue')
 
     relation_name: Optional[str] = FieldInfo(alias='relationName')
