@@ -1,10 +1,10 @@
-from typing import Dict, Optional
+from typing import Mapping, Optional
 from .._types import TypedDict
 
 
 __all__ = (
+    'PartialModel',
     'PartialModelField',
-    'PartialModelFields',
 )
 
 
@@ -17,4 +17,7 @@ class PartialModelField(TypedDict):
     is_relational: bool
 
 
-PartialModelFields = Dict[str, PartialModelField]
+class PartialModel(TypedDict):
+    name: str
+    from_model: str
+    fields: Mapping[str, PartialModelField]
